local util = require("mer.realisticArchery.util")
local config = util.config
local mcmConfig = mwse.loadConfig(config.configPath, config.mcmDefault)

local LINKS_LIST = {
    {
        text = "Historique (VO)",
        url = "https://github.com/jhaakma/auto-attack/releases"
    },
    -- {
    --     text = "Wiki",
    --     url = "https://github.com/jhaakma/auto-attack/wiki"
    -- },
    {
        text = "Page Nexus",
        url = "https://www.nexusmods.com/morrowind/mods/51348"
    },
    {
        text = "Ko-fi",
        url = "https://ko-fi.com/merlord"
    },
}
local CREDITS_LIST = {
    {
        text = "Par Merlord",
        url = "https://www.nexusmods.com/users/3040468?tab=user+files",
    },
}

local function addSideBar(component)
    local versionText = string.format(config.static.modName)
    component.sidebar:createCategory(versionText)
    component.sidebar:createInfo{ text = config.static.modDescription}

    local linksCategory = component.sidebar:createCategory("Liens")
    for _, link in ipairs(LINKS_LIST) do
        linksCategory:createHyperLink{ text = link.text, url = link.url }
    end
    local creditsCategory = component.sidebar:createCategory("Crdits")
    for _, credit in ipairs(CREDITS_LIST) do
        creditsCategory:createHyperLink{ text = credit.text, url = credit.url }
    end
end

local function registerMCM()
    local template = mwse.mcm.createTemplate{ name = config.static.modName,}
    template.onClose = function()
        config.save(mcmConfig)
    end
    template:register()

    local page = template:createSideBarPage{ label = "Paramtres"}
    addSideBar(page)

    page:createYesNoButton{
        label = "Activer le mod",
        description = "Active ou dsactive Archerie raliste.",
        variable = mwse.mcm.createTableVariable{ id = "enabled", table = mcmConfig }
    }

    page:createSlider{
        label = "Ecart maximal : %s degrs",
        description = "Dtermine de combien de degrs un projectile peut s'carter du point de vise lorsqu'il est lanc. Pondr par le talent de Prcision du PNJ/joueur qui lance le projectile."
          .. string.format(" Default: %s%%", config.mcmDefault.maxNoise),
        variable = mwse.mcm.createTableVariable{ id = "maxNoise", table = mcmConfig },
        min = 0,
        max = 100,
        jump = 5,
        step = 1
    }

    page:createSlider{
        label = "Distance minimale pour les pleins dgts (pour le plus bas niveau en Prcision) : %s",
        description = "Dtermine la distance minimale  laquelle doit se trouver un projectile pour infliger le maximum de dgts. Cette distance est divise par 2 quand le talent de Prcision vaut 100."
            .. string.format(" Par dfaut : %s", config.mcmDefault.minDistanceFullDamage),
        variable = mwse.mcm.createTableVariable{ id = "minDistanceFullDamage", table = mcmConfig },
        min = 0,
        max = 5000,
        jump = 100,
        step = 1
    }

    page:createSlider{
        label = "Rduction maximale de dgts  courte porte : %s %%",
        description = "Dtermine la rduction maximale de dgts que subit un projectile lorsqu'il est lanc  courte porte sur une cible."
            .. string.format(" Par dfaut : %s %%", config.mcmDefault.maxCloseRangeDamageReduction),
        variable = mwse.mcm.createTableVariable{ id = "maxCloseRangeDamageReduction", table = mcmConfig },
        min = 0,
        max = 100,
        jump = 5,
        step = 1
    }

    page:createSlider{
        label = "Multiplicateur de discrtion : %s %%",
        description = "Dtermine le pourcentage de rduction d'cart lorsqu'un attaquant est en mode Discrtion."
            .. string.format(" Par dfaut : %s %%", config.mcmDefault.sneakReduction),
        variable = mwse.mcm.createTableVariable{ id = "sneakReduction", table = mcmConfig },
        min = 0,
        max = 100,
        jump = 5,
        step = 1
    }


    page:createDropdown{
        label = "Niveau de journalisation",
        description = "Dfinit le niveau de journalisation du mod pour le fichier mwse.log. Laissez-le sur INFO  moins que vous n'ayez besoin de faire du dbuggage.",
        options = {
            { label = "TRACE", value = "TRACE"},
            { label = "DEBUG", value = "DEBUG"},
            { label = "INFO", value = "INFO"},
            { label = "ERROR", value = "ERROR"},
            { label = "NONE", value = "NONE"},
        },
        variable =  mwse.mcm.createTableVariable{ id = "logLevel", table = mcmConfig },
        callback = function(self)
            for _, logger in pairs(util.loggers) do
                logger:setLogLevel(self.variable.value)
            end
        end
    }
end
event.register("modConfigReady", registerMCM)
